Update of /cvsroot/ispman/ispman/lib/ISPMan
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv10740/lib/ISPMan
Modified Files:
Tag: rel_1_1-bugfixes
ApacheMan.pm
Log Message:
fixed bug: error on vhost creation with non-dns domain
Index: ApacheMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/ApacheMan.pm,v
retrieving revision 1.45
retrieving revision 1.45.2.1
diff -u -d -r1.45 -r1.45.2.1
--- ApacheMan.pm 18 Jan 2004 02:35:38 -0000 1.45
+++ ApacheMan.pm 5 Feb 2004 08:38:57 -0000 1.45.2.1
@@ -341,17 +341,20 @@
# write data to LDAP
if (! $self->addNewEntryWithData($dn, $data)){ return 0};
-
- for (@$webhosts){
-
- # add new A-record for webhost
- # NOTICE: for multiple webhosts this will create multiple a-records which
- # will act as simple round-robin loadbalancing.
- # Change them manually for proper hardware loadbalancing!
- $self->addVhostDNSRecord($r->param("ispmanDomain"), $r->param("ispmanVhostName"), $self->getHostIp($_));
- # add process fro vhost creation
- $self->addProcessToHost($r->param("ispmanDomain"), $_, "AddVirtualHost", $r->param("ispmanVhostName"));
+ # add new A-record for webhost(s) if domain is primary
+ if ($domain_info->{'ispmanDomainType'} eq "primary"){
+ for (@$webhosts){
+
+ # add new A-record for webhost
+ # NOTICE: for multiple webhosts this will create multiple a-records which
+ # will act as simple round-robin loadbalancing.
+ # Change them manually for proper hardware loadbalancing!
+ $self->addVhostDNSRecord($r->param("ispmanDomain"), $r->param("ispmanVhostName"), $self->getHostIp($_));
+
+ # add process fro vhost creation
+ $self->addProcessToHost($r->param("ispmanDomain"), $_, "AddVirtualHost", $r->param("ispmanVhostName"));
+ }
}
# add process for vhost directory creation
-------------------------------------------------------
The SF.Net email is sponsored by EclipseCon 2004
Premiere Conference on Open Tools Development and Integration
See the breadth of Eclipse activity. February 3-5 in Anaheim, CA.
http://www.eclipsecon.org/osdn
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.